[−][src]Crate font8x8
8x8 monochrome bitmap fonts for rendering
This crate contains a Rust implementation of a public domain 8-bit by 8-bit font.
See '../README.md`.
On the miscellanous characters included
These characters are provided as-is, and some don't have a proper unicode point.
They are provided in the MISC and SGA contants. For a description, please
read the constant documentation.
Credits
Initially extracted from an asm file, fetched from a now broken link:
http://dimensionalrift.homelinux.net/combuster/mos3/?p=viewsource&file=/modules/gfx/font8_8.asm
It was then ported to a C header file, also in the Public Domain, https://github.com/dhepper/font8x8.
This crate is an extension of that work.
Re-exports
pub use self::unicode::FontUnicode; |
pub use self::unicode::UnicodeFonts; |
Modules
| legacy | Re-export the original |
| unicode | Unicode support for 8x8 fonts. |
Structs
| FromUtf16Error | A possible error value when converting a |
Constants
| BASIC_FONTS | A convenient constant for Basic Latin fonts ( |
| BASIC_UNICODE | A constant |
| BLOCK_FONTS | A convenient constant for Block Element fonts ( |
| BLOCK_UNICODE | A constant |
| BOX_FONTS | A convenient constant for Box Element fonts ( |
| BOX_UNICODE | A constant |
| GREEK_FONTS | A convenient constant for Greek fonts ( |
| GREEK_UNICODE | A constant |
| HIRAGANA_FONTS | A convenient constant for Hiragana fonts ( |
| HIRAGANA_UNICODE | A constant |
| LATIN_FONTS | A convenient constant for Extended Latin fonts ( |
| LATIN_UNICODE | A constant |
| MISC_FONTS | A convenient constant for Miscellanous fonts ( |
| MISC_UNICODE | A constant |
| SGA_FONTS | A convenient constant for special SGA fonts ( |
| SGA_UNICODE | A constant |